Additional PowerConsole Commands — Firebird Pack for PowerConsole v0.9.1 documentation

### Navigation

- index
- next |
- previous |
- Firebird Pack for PowerConsole v0.9.1 documentation »

# Additional PowerConsole Commands

Firebird Pack also installs additional commands to the PowerConsole. Some commands are equivalents of ISQL commands, some are completely new.

Note

All installed commands use case insensitive keywords.

## CONNECT

Attach to the Firebird database. Usage:

    CONNECT 'dsn or db' [HOST host][USER 'user'][PASSWORD 'password'][CACHE int ][ROLE 'role'][AS var][;]

If connection is sucessfuly established, this database connection is set as main working database. Database object is stored and accessible under default alias “db” or as alias specified by optional AS argument. If alias name is already used for other attached database, this database is disconnected.

## DISCONNECT

Disconnects from attached Firebird database. Usage:

    DISCONNECT [dbvar]

Without argument, it will disconnect from current working database. If argument is specified, it must be a name of previously connected database (implicit name ‘db’ or name specified by AS argument) that should be disconnected. If disconnected database is current working database, then current working database is set to other connected database if there is any.

## READY

This command shows list of attached Firebird databases or selects the working database. Usage:

    READY [dbvar]

Without argument, it will list all attached databases. If argument is specified, it must be a name of previously connected database (implicit name ‘db’ or name specified by AS argument).

## SHOW commands

This pack installs several extensions for standard SHOW command to examine database objects equivalent to ISQL SHOW commands:

    SHOW DATABASE [<dbvar>]

        Detail about current or specified attached database.

    SHOW [SYSTEM] TABLES | TABLE <dbident> [IN <dbvar>]
    SHOW [SYSTEM] INDICES | INDEX <dbident> [IN <dbvar>]
    SHOW [SYSTEM] DOMAINS | DOMAIN <dbident> [IN <dbvar>]
    SHOW [SYSTEM] PROCEDURES | PROCEDURE <dbident> [IN <dbvar>]
    SHOW [SYSTEM] TRIGGERS | TRIGGER <dbident> [IN <dbvar>]
    SHOW [SYSTEM] VIEWS | VIEW <dbident> [IN <dbvar>]
    SHOW [SYSTEM] GENERATORS | GENERATOR <dbident> [IN <dbvar>]
    SHOW [SYSTEM] FUNCTIONS | FUNCTION <dbident> [IN <dbvar>]
    SHOW EXCEPTIONS | EXCEPTION <dbident> [IN <dbvar>]
    SHOW CHARACTER SETS | CHARACTER SET <dbident> [IN <dbvar>]
    SHOW COLLATIONS | COLLATION <dbident> [IN <dbvar>]
    SHOW ROLES | ROLE <dbident> [IN <dbvar>]

        List of object names or object details in current or specified attached database.

All these commands work on main attached database by default, but can also operate on other attached databases via direct specification of Database object name.

Note

For greater compatibility with ISQL, these commands accept optional semicolon terminator.

## SET commands

This pack supports subset of ISQL SET commands:

    SET                      Display current SET options.
    SET SQL DIALECT <num>    Sets SQL DIALECT used for new connection or created databases.
    SET AUTO[DDL] [ON | OFF] Toggle autocommit of DDL statements.
    SET NAMES <charset>      Set name of runtime character set.
    SET PLAN [ON | OFF]      Toggle display of query access plan.
    SET PLANONLY [ON | OFF]  Toggle display of query plan without executing.

Note

For greater compatibility with ISQL, you may optionally end each command with semicolon.

## SET TERM

It’s actually a standard PowerConsole command, but it works and should be used in the same way as ISQL SET TERM command.

### Navigation

- index
- next |
- previous |
- Firebird Pack for PowerConsole v0.9.1 documentation »